@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::elements;
 use strict;
 use Acme::MetaSyntactic::Locale;
 our @ISA = qw( Acme::MetaSyntactic::Locale );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 1;
 
@@ -30,7 +30,11 @@ Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
 Updated with an C<=encoding> pod command in version 1.001,
-published on May 14,2012
+published on May 14, 2012.
+
+Updated with Copernicium, Flerovium, and Livermorium by Abigail
+in version 1.002,
+published on June 4, 2012.
 
 =head1 SEE ALSO
 
@@ -47,7 +51,7 @@ Fe Co Ni Cu Zn Ga Ge As Se Br Ky Rb Sr Y  Zr Nb Mo Tc Ru Rh Pd Ag Cd In
 Sn Sb Te I  Xe Cs Ba La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb Lu Hf Ta
 W  Re Os Ir Pt Au Hg Tl Pb Bi Po At Rn Fr Ra Ac Th Pa U  Np Pu Am Cm Bk
 Cf Es Fm Md Bo Lr Rf Db Sg Bh Hs Mt Ds Rg
-Uub Uut Uuq Uup Uuh Uus Uuo
+Cn Uut Fl Uup Lv Uus Uuo
 # names en
 hydrogen helium lithium beryllium boron carbon nitrogen oxygen fluorine
 neon sodium magnesium aluminum silicon phosphorus sulfur chlorine argon
@@ -62,8 +66,8 @@ osmium iridium platinum gold mercury thallium lead bismuth polonium
 astatine radon francium radium actinium thorium protactinium uranium
 neptunium plutonium americium curium berkelium californium einsteinium
 fermium mendelevium nobelium lawrencium rutherfordium dubnium seaborgium
-bohrium hassium meitnerium darmstadtium roentgenium ununbium ununtrium
-ununquadium ununpentium ununhexium ununseptium ununoctium
+bohrium hassium meitnerium darmstadtium roentgenium copernicium ununtrium
+flerovium ununpentium livermorium ununseptium ununoctium
 # names fr
 hydrogene helium lithium beryllium bore carbone azote oxygene fluor
 neon sodium magnesium aluminium silicium phosphore soufre chlore argon
@@ -78,6 +82,6 @@ mercure thallium plomb bismuth polonium astate radon francium radium
 actinium thorium protactinium uranium neptunium plutonium americium
 curium berkelium californium einsteinium fermium mendelevium nobelium
 lawrencium rutherfordium dubnium seaborgium bohrium hassium meitnerium
-darmstadtium roentgenium ununbium ununtrium ununquadium ununpentium
-ununhexium ununseptium ununoctium
+darmstadtium roentgenium copernicium ununtrium flerovium ununpentium
+livermorium ununseptium ununoctium
 
