@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::linux;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 our %Remote = (
     source  => 'http://distrowatch.com/',
@@ -62,6 +62,9 @@ published on May 7, 2012.
 Updated from the source web site for v1.001,
 published in Acme-MetaSyntactic-Themes v1.003, May 28, 2012.
 
+Updated from the source web site for v1.002,
+published in Acme-MetaSyntactic-Themes v1.007, June 25, 2012.
+
 =head1 DEDICATION
 
 This module is dedicated to the Linux kernel for its fifteenth
@@ -127,7 +130,6 @@ CAINE
 Caixa_M_gica
 Calculate
 Canaima
-Caos
 C_tix
 CCux
 CDlinux
@@ -197,6 +199,7 @@ Inquisitor
 Insigne
 IPCop
 IPFire
+iQunix
 Jibbed
 JoLinux
 Joli_OS
@@ -281,7 +284,6 @@ PAIPIX
 paldo
 PapugLinux
 Parabola
-Pardus
 Parsix
 Parted_Magic
 PC_BSD
