@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -64,6 +64,9 @@ published on May 7, 2012.
 Updated from the source web site for v1.001,
 published in Acme-MetaSyntactic-Themes v1.003, May 28, 2012.
 
+Updated from the source web site for v1.002,
+published in Acme-MetaSyntactic-Themes v1.007, June 25, 2012.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -106,6 +109,7 @@ ABEROHAM
 ABH
 ABHAS
 ABHIDHAR
+ABHIISNOT
 ABHINAY
 ABHISHEK
 ABHISINGH
@@ -148,6 +152,7 @@ ACKI
 ACMCMEN
 ACOBURN
 ACOTIE
+ACPGUEDES
 ACRABB
 ACRAIG
 ACRAWFORD
@@ -190,6 +195,7 @@ ADRIAN
 ADRIANA
 ADRIANWIT
 ADRIS
+ADROFFNER
 ADTIM
 ADUITSIS
 ADULAU
@@ -308,6 +314,7 @@ ALBERS
 ALBOVA
 ALD
 ALDICKEY
+ALDOBRANT
 ALEC
 ALECH
 ALECS
@@ -436,6 +443,7 @@ ANDERS
 ANDI
 ANDK
 ANDMEN
+ANDOR
 ANDOT
 ANDOZER
 ANDRE
@@ -682,6 +690,7 @@ AUBRYF
 AUDREYT
 AUFFLICK
 AUGER
+AUGGY
 AUGIE
 AUGUSTO
 AUKJAN
@@ -832,6 +841,7 @@ BBUM
 BBURCH
 BBUSS
 BBYRD
+BCARMER
 BCARROLL
 BCBAILEY
 BCDE
@@ -866,6 +876,7 @@ BEADSLAND
 BEANS
 BEANZ
 BEARSHEN
+BEAST
 BEASTVOL
 BEATNIK
 BEAU
@@ -1042,6 +1053,7 @@ BLHOTSKY
 BLILBURNE
 BLINCHIK
 BLM
+BLMARKET
 BLNOARD
 BLOGALEX
 BLOM
@@ -1078,6 +1090,7 @@ BMXKRIS
 BNEGRAO
 BOADLER
 BOAG
+BOATES
 BOB
 BOBERNST
 BOBF
@@ -1145,6 +1158,7 @@ BOYSIE
 BOZO
 BOZZIO
 BPANNIER
+BPATEL
 BPAULSEN
 BPEDERSE
 BPETERING
@@ -1231,6 +1245,7 @@ BRUNODIAZ
 BRUNORC
 BRUNOV
 BRX
+BRYAN
 BRYCE
 BRYURECKA
 BSAGO
@@ -1345,6 +1360,7 @@ CAMERB
 CAMERON
 CAMSTUART
 CANADA
+CANECA
 CANGELL
 CANID
 CANONB
@@ -1486,9 +1502,11 @@ CHARTGRP
 CHAS
 CHATEAU
 CHCHCH
+CHE
 CHEAKO
 CHEN
 CHENGANG
+CHENRYN
 CHENXIN
 CHENXUAN
 CHENYR
@@ -1653,6 +1671,7 @@ CNANGEL
 CNATION
 CNG
 CNHACKTNT
+CNIGHS
 CNLAVY
 CNRDEEIO
 CNX
@@ -1776,6 +1795,7 @@ CSALAT
 CSANDEEP
 CSARVA
 CSCHAEFER
+CSCHWENZ
 CSCM
 CSEATON
 CSELLEG
@@ -1798,6 +1818,7 @@ CTI
 CTILMES
 CTIMMER
 CTLARSEN
+CTREPTOW
 CTRLSOFT
 CTRONDLP
 CTWETEN
@@ -2056,7 +2077,9 @@ DEC
 DECASM
 DECAY
 DECIUS
+DEDMEDVED
 DEEMON
+DEENEWCUM
 DEEPAK
 DEEPAKG
 DEEPAN
@@ -2113,6 +2136,7 @@ DETZ
 DETZOLD
 DEUSX
 DEVDOS
+DEVELO
 DEVEN
 DEVIS
 DEVMORFO
@@ -2353,6 +2377,7 @@ DOUGB
 DOUGDUDE
 DOUGL
 DOUGLEITH
+DOUGLISH
 DOUGLUCE
 DOUGM
 DOUGRAY
@@ -2476,6 +2501,7 @@ DTRISCHUK
 DTURLEY
 DUANEG
 DUBEX
+DUCKBILL
 DUCKYYAZY
 DUEBERB
 DUELAFN
@@ -2505,6 +2531,7 @@ DVWRIGHT
 DWARREN
 DWATSON
 DWC
+DWCARDER
 DWELZEL
 DWHEELER
 DWILSON
@@ -2525,6 +2552,8 @@ DYKER
 DYLAN
 DYLUNIO
 DYNULAX
+DYOUNG
+DYPSILON
 DZEMA
 DZHARIY
 DZHUO
@@ -2716,6 +2745,7 @@ ERICJH
 ERICKD
 ERICM
 ERICW
+ERICYE
 ERIK
 ERIKE
 ERIKH
@@ -3209,6 +3239,7 @@ GNAT
 GNATYNA
 GNAZAREY
 GNB
+GNDPR
 GNG
 GNO
 GNOME
@@ -3235,6 +3266,7 @@ GOPI
 GORAXE
 GORD
 GORK
+GORTAN
 GOSHA
 GOSSAMER
 GOURAV
@@ -3299,6 +3331,7 @@ GROMMIER
 GROOVIS
 GROSSMANN
 GROUSSE
+GROVED
 GRUBER
 GRUDZIAR
 GRUNDEI
@@ -3354,6 +3387,7 @@ GUYDX
 GVENKAT
 GWADEJ
 GWARD
+GWARMAN
 GWELCH
 GWG
 GWHITE
@@ -3451,6 +3485,7 @@ HCARVEY
 HCCHIEN
 HCKKID
 HDAICHI
+HDANAK
 HDANIEL
 HDIAS
 HDM
@@ -3460,6 +3495,7 @@ HDS
 HEBELT
 HEDWIG
 HEGEMANP
+HEIKKI
 HEIKO
 HEIKOK
 HEIKOWU
@@ -3587,6 +3623,7 @@ HORNBURG
 HORNET
 HORROCKS
 HORSHACK
+HORST
 HOSI
 HOTSPUR
 HOTZE
@@ -3645,6 +3682,7 @@ HZHOU
 HZLNT
 IAIN
 IAINT
+IAMB
 IAMCAL
 IAN
 IANB
@@ -3675,6 +3713,7 @@ ICHE
 ICHI
 ICHLADIL
 ICHUDOV
+ICIBIN
 ICK
 ICKHABOD
 ICLARK
@@ -3695,6 +3734,7 @@ IFIM
 IFLAN
 IFOMICHEV
 IFROL
+IFTEKHAR
 IFUSCHINI
 IGERLACH
 IGORM
@@ -3855,6 +3895,7 @@ JACKTAO
 JACM
 JACO
 JACOB
+JACOBROSE
 JACQUELIN
 JAD
 JADAMS
@@ -3905,6 +3946,7 @@ JANDRAS
 JANDREW
 JANDREWS
 JANERT
+JANEZHANG
 JANL
 JANNINO
 JANP
@@ -3919,6 +3961,7 @@ JAOS
 JAR
 JARED
 JARIAALTO
+JARICH
 JARLE
 JARTYMIAK
 JARW
@@ -4149,6 +4192,7 @@ JGEYER
 JGIBSON
 JGILB
 JGITLIN
+JGK
 JGL
 JGLICK
 JGMYERS
@@ -4204,6 +4248,7 @@ JIGSO
 JIK
 JILA
 JIM
+JIMBOB
 JIMBOX
 JIMFL
 JIMI
@@ -4219,6 +4264,7 @@ JIRO
 JIRWIN
 JJACK
 JJARVINEN
+JJCARMAN
 JJDG
 JJFUMERO
 JJGREEN
@@ -4285,6 +4331,7 @@ JLOPHTY
 JLOUDER
 JLOUISBIZ
 JLOWREY
+JLRUSH
 JLSCHWAB
 JLSPEARS
 JMAC
@@ -4355,6 +4402,7 @@ JNWHITLEY
 JOAKIMBS
 JOANMG
 JOAO
+JOAOCOSTA
 JOAOP
 JOBA
 JOBERO
@@ -4365,6 +4413,7 @@ JOEATZ
 JOEHIL
 JOEJIANG
 JOELH
+JOELJAC
 JOENIO
 JOEOFCLEW
 JOEP
@@ -4415,6 +4464,7 @@ JONBROWN
 JONE
 JONFM
 JONG
+JONI
 JONIONS
 JONJ
 JONJAY
@@ -4445,6 +4495,7 @@ JOSHUAG
 JOSHW
 JOST
 JOSTEN
+JOT
 JOUKE
 JOVAL
 JOY
@@ -4733,6 +4784,7 @@ KCIVEY
 KCK
 KCLARK
 KCODY
+KCOMKAR
 KCOTT
 KCOWGILL
 KCWU
@@ -4757,6 +4809,7 @@ KENMACF
 KENNEDYH
 KENNETHK
 KENNYG
+KENO
 KENSHAN
 KENSHIN
 KENTARO
@@ -4785,6 +4838,7 @@ KEVINJ
 KEVINO
 KEVINR
 KEVINRICE
+KEVINZ
 KEVJSHEA
 KEVLINDEV
 KEVORKYAN
@@ -4811,6 +4865,7 @@ KHAREC
 KHASELY
 KHEDIN
 KHEMICALS
+KHM
 KHOELZER
 KHOERLING
 KHOLZ
@@ -4861,6 +4916,7 @@ KIXX
 KIZ
 KJACKSON
 KJALB
+KJAM
 KJEKJO
 KJELLM
 KJETIL
@@ -4904,6 +4960,7 @@ KNOPKE
 KNORR
 KNOTTY
 KNOWLES
+KNSHAUM
 KNTH
 KNTONAS
 KOADMAN
@@ -5328,6 +5385,7 @@ LSTAF
 LSTEVENS
 LSTGEORGE
 LTBOOTS
+LTHARRIS
 LTHEGLER
 LTOETSCH
 LTP
@@ -5374,6 +5432,7 @@ LYL
 LYNX
 LYOKATO
 LYTREAN
+LYUAN
 LYUMING
 LZAP
 LZE
@@ -5407,6 +5466,7 @@ MADWOLF
 MADZ
 MAESTRO
 MAFR
+MAG
 MAGGIEXYZ
 MAGH
 MAGICIAN
@@ -5436,6 +5496,7 @@ MAJA
 MAJCHER
 MAJENSEN
 MAJESTIC
+MAJLIS
 MAK
 MAKAMAKA
 MAKAROW
@@ -5466,6 +5527,7 @@ MANDY
 MANFREDI
 MANGARU
 MANI
+MANIK
 MANISH
 MANIWHEEL
 MANJUNATH
@@ -5569,6 +5631,7 @@ MARTYLOO
 MARTYNOFF
 MARTYNOV
 MARTYZZ
+MARVIN
 MARWATK
 MARWIL
 MARYA
@@ -5664,6 +5727,7 @@ MBERENDS
 MBERG
 MBETHKE
 MBGRAY
+MBHALL
 MBITTER
 MBKODOS
 MBLAZ
@@ -5983,6 +6047,7 @@ MKANAT
 MKENNEDY
 MKHRAPOV
 MKI
+MKJELLMAN
 MKMUELLER
 MKODERER
 MKOSSATZ
@@ -6010,6 +6075,7 @@ MLONGTIN
 MLRU
 MLS
 MLUKER
+MLX
 MMABRY
 MMACHADO
 MMAKAAY
@@ -6020,6 +6086,7 @@ MMASTERS
 MMATHEWS
 MMAURICE
 MMBK
+MMCCLENN
 MMCGILLIS
 MMCLAGAN
 MMCLERIC
@@ -6039,6 +6106,7 @@ MMORENO
 MMORGAN
 MMOYLE
 MMUELLER
+MMULLI
 MMUSGROVE
 MMV
 MMWEBER
@@ -6099,6 +6167,7 @@ MORTENF
 MORTIY
 MORTY
 MORUNGOS
+MOSBOY
 MOSCONI
 MOSES
 MOSHEGOOD
@@ -6149,6 +6218,7 @@ MRDINI
 MRDVT
 MREIMANN
 MRENZ
+MRF
 MRFELTON
 MRG
 MRGRIPH
@@ -6241,6 +6311,7 @@ MSULLIVAN
 MTADEL
 MTHOMAS
 MTHURN
+MTINBERG
 MTIRAMANI
 MTL
 MTMAIL
@@ -6307,6 +6378,7 @@ MYFINDER
 MYKL
 MYNEID
 MYRTSCHT
+MYSFITT
 MYSOCIETY
 MYSTERYTE
 MYSZ
@@ -6316,6 +6388,7 @@ MZIESCHA
 MZRAHMAN
 MZSANFORD
 NAB
+NABCIF
 NABESHIMA
 NABOJ
 NABU
@@ -6577,6 +6650,7 @@ NTSUTSUMI
 NUANCE
 NUBA
 NUCLON
+NUCWIN
 NUF
 NUFFIN
 NURAB
@@ -6713,6 +6787,7 @@ OTY
 OUBIWANN
 OUEST
 OVAL
+OVENMAN
 OVERMARS
 OVID
 OWEN
@@ -6766,6 +6841,7 @@ PASP
 PASSOS
 PASTI
 PATBAKER
+PATBHATK
 PATCH
 PATL
 PATM
@@ -6952,6 +7028,7 @@ PHILIPS
 PHILKIME
 PHILLIPS
 PHILLTYLR
+PHILLUP
 PHILMI
 PHILOU
 PHINYX
@@ -7099,6 +7176,7 @@ POUM
 POWERMAN
 POZNICK
 PPANT
+PPATTHAR
 PPISAR
 PPUTNAM
 PRABHUCH
@@ -7315,6 +7393,7 @@ RAYM
 RAYMOR
 RAYNERLUC
 RAYT
+RAZ
 RAZINF
 RAZOR
 RAZVANM
@@ -7432,6 +7511,7 @@ RGILIAM
 RGLAUE
 RGRAFF
 RGRAHAM
+RGRAU
 RGRAVES
 RGRJR
 RGS
@@ -7468,6 +7548,7 @@ RICHDAWE
 RICHIH
 RICK
 RICKEST
+RICKFORD
 RICKI
 RICKM
 RICKYLEVI
@@ -7611,6 +7692,7 @@ ROHAN
 ROHANK
 ROHANPM
 ROHITM
+ROHLFSC
 ROKR
 ROLAND
 ROLFYONE
@@ -7657,6 +7739,7 @@ RPEASE
 RPETRE
 RPETTETT
 RPHANEY
+RPICARD
 RPIKKARA
 RPKELLY
 RPLATEL
@@ -7721,6 +7804,7 @@ RUSSELLJ
 RUSSELLP
 RUSSOZ
 RUSST
+RUSSUM
 RUSTYP
 RUTSCHLE
 RUYK
@@ -7734,6 +7818,7 @@ RVDP
 RVGOKHALE
 RVIREDAY
 RVMINDSTP
+RVNCERR
 RVOSA
 RVR
 RVSUTHERL
@@ -8012,6 +8097,7 @@ SFRYER
 SGEL
 SGERSTEN
 SGIKAS
+SGLADKOV
 SGMIANO
 SGODIN
 SGOELDNER
@@ -8093,6 +8179,7 @@ SHMEM
 SHMORIMO
 SHOEPHONE
 SHOGE
+SHOK
 SHOLDEN
 SHOMODJ
 SHONORIO
@@ -8134,6 +8221,7 @@ SIGURKO
 SIGZERO
 SILASMONK
 SILI
+SILVAN
 SILVER
 SILVIOQ
 SIMATIKA
@@ -8160,6 +8248,7 @@ SIMPLEX
 SIMRAN
 SINI
 SINISTER
+SIRMXE
 SIRROBERT
 SISYPHUS
 SITETECH
@@ -8176,6 +8265,7 @@ SJENKINS
 SJFD
 SJH
 SJHAWTIN
+SJM
 SJN
 SJO
 SJOHNSTON
@@ -8236,6 +8326,7 @@ SLSTAT
 SLU
 SMAK
 SMALHOTRA
+SMALLEYD
 SMALLFISH
 SMALLPOND
 SMALYSHEV
@@ -8491,6 +8582,7 @@ STEVIEO
 STFN
 STHEBERT
 STHOMAS
+STICKPIN
 STIG
 STIGMATA
 STIGPJE
@@ -8534,6 +8626,7 @@ STURM
 STWIGGER
 STYPNOW
 SUAVEANT
+SUBBU
 SUBSTACK
 SUDIP
 SUE
@@ -8566,6 +8659,7 @@ SUPERL
 SURCOUF
 SURESHG
 SURESHRAM
+SURYA
 SUTCH
 SUWER
 SUZUKI
@@ -8739,6 +8833,7 @@ TEHSI
 TEKE
 TEKFU
 TELIN
+TELKINS
 TELS
 TEMPALTE
 TEMPIRE
@@ -8966,6 +9061,7 @@ TORG
 TORRANCEW
 TORU
 TOSHIFJW
+TOSHIOITO
 TOST
 TOSTI
 TOWLIEBAN
@@ -9250,10 +9346,13 @@ VLEERTJE
 VLYON
 VMAN
 VMARCHEN
+VMIKULIC
 VMOISEEV
 VMORAL
 VMS
 VMSML
+VMSPB
+VNAIPAUL
 VODKAU
 VOEGELAS
 VOICET
@@ -9297,6 +9396,7 @@ WAIDER
 WAKAPON
 WALDI
 WALKER
+WALLISDS
 WALLMARI
 WALSHAM
 WALSHTP
@@ -9359,6 +9459,7 @@ WERRIE
 WESAL
 WESJDJ
 WESLEYYE
+WESM
 WESTRATE
 WETERS
 WEZ
@@ -9445,6 +9546,7 @@ WOLF
 WOLFEN
 WOLFMAN
 WOLFSAGE
+WOLFTOWER
 WOLLMERS
 WOLS
 WOLVERIAN
@@ -9574,6 +9676,7 @@ YAMATO
 YANA
 YANBE
 YANICK
+YANKAITUO
 YANMAR
 YANN
 YANNK
@@ -9582,6 +9685,7 @@ YAPPO
 YARBER
 YARGEVAD
 YARON
+YARROW
 YASHA
 YASU
 YASUHIRO
@@ -9742,6 +9846,7 @@ ZIM
 ZIMAGE
 ZIMMERR
 ZINCDEV
+ZIPPO
 ZIPPY
 ZIYA
 ZJFDLUT
@@ -9751,6 +9856,7 @@ ZLIPTON
 ZMAN
 ZMIJ
 ZMUGHAL
+ZMYRGEL
 ZOCCAV
 ZOFFIX
 ZOGZAPPER
