@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pm_groups;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -75,6 +75,9 @@ published on May 7, 2012.
 Updated from the source web site for v1.001,
 published in Acme-MetaSyntactic-Themes v1.003, May 28, 2012.
 
+Updated from the source web site for v1.002,
+published in Acme-MetaSyntactic-Themes v1.007, June 25, 2012.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -298,3 +301,4 @@ Mumbai_pm
 Weston_pm
 Cluj_pm
 Niigata_pm
+Hardware_pm
